#include "parts/m55800/lib_m55800.h"
#include "drivers/capture/capture.h"
#include "drivers/wait/wait.h"
#include "parts/m55800/eb55.h"
#include "menu.h"

//Values found in ezLCD002_Manual.pdf



//LCD Communication Parameters
#define LCD_BAUD 115200


//for VISUAL STUDIO ONLY

//copied from tetris.h
#define CLASS_TETRAD 0
#define TWIST_TETRAD 1
#define STRAT_TETRAD 2



//General
#define     LCD_CLS	                0x21
#define     LCD_LIGHT_ON			0x22
#define     LCD_LIGHT_OFF			0x23
#define     LCD_SET_COLOR			0x24
#define     LCD_SET_XY				0x25

//Points
#define     LCD_PLOT				0x26
#define     LCD_PLOT_XY				0x27

//Lines
#define     LCD_H_LINE				0x40
#define     LCD_V_LINE				0x41
#define     LCD_LINE_TO_XY			0x28
//Figures
#define 	LCD_ARC					0x2F	
#define 	LCD_CIRCLE_R			0x29
#define 	LCD_CIRCLE_R_FILL		0x39
#define 	LCD_BOX					0x42
#define 	LCD_BOX_FILL			0x43

//Bitmaps
#define 	LCD_PUT_BITMAP			0x2E
#define 	LCD_PUT_ICON			0x57
#define 	LCD_PUT_SF_ICON			0x58
#define 	LCD_PICTURE				0x2A

//Text and Fonts
#define 	LCD_SELECT_FONT			0X2B
#define 	LCD_SET_BG_COLOR		0X34
#define 	LCD_TEXT_NORTH			0x60
#define 	LCD_TEXT_EAST			0x61
#define 	LCD_TEXT_SOUTH			0x62
#define 	LCD_TEXT_WEST			0x2F
#define 	LCD_PRINT_CHAR			0x2C
#define 	LCD_PRINT_CHAR_BG		0x3C
#define 	LCD_PRINT_STRING		0x2D
#define 	LCD_PRINT_STRING_BG		0x3D

//Color Map									
#define  	LCD_BLACK     			0x00	//%00000000 
#define  	LCD_RED       			0x07	//%00000111
#define     LCD_ORANGE              0x2F    //%00101111
#define  	LCD_YELLOW    			0x3F	//%00111111
#define  	LCD_GREEN     			0x38	//%00111000
#define 	LCD_CYAN				0xF8	//%11111000
#define  	LCD_BLUE      			0xC0	//%11000000        
#define  	LCD_NAVY      			0x80	//%10000000
#define  	LCD_PURPLE    			0xC4	//%11000100 
#define  	LCD_WHITE     			0xFF	//%11111111

#define 	LCD_BOMB 				LCD_YELLOW
//LCD INFO
#define 	LCD_MAX_HEIGHT			159
#define		LCD_MAX_WIDTH			249

#define		LCD_GRID_W				79
#define		LCD_GRID_H				LCD_MAX_HEIGHT

#define     LCD_BLOCK_PX            8       //Used to find the Origin of the Block
#define     LCD_BLOCK_SIZ           6

//INFO BLOCK 
#define 	LCD_INFO_ORG_X			80		//ORIGIN of the INFO BLOCK
#define 	LCD_INFO_ORG_Y			0
#define 	LCD_INFO_END_X			190		//Bottom Right Corner of INFO BLOCK
#define		LCD_INFO_END_Y			LCD_MAX_HEIGHT				

#define 	LCD_STR_PLAYPAUSE		"Play/Pause"
#define 	LCD_STR_RESTART			"Restart"
#define		LCD_STR_QUIT			"Quit"
#define		LCD_STR_CLASS			"Classic"
#define		LCD_STR_TWIST			"Twisted"
#define		LCD_STR_STRAT			"Strategic"
#define 	LCD_MAX_STR				7 // max number of characters for lines  

//LCD Function Prototypes
void Cls();
void LightOn();
void LightOff();
void SetColor(u_int color);
void SetXY(u_int X, u_int Y);
void Plot();
void PlotXY(u_int X, u_int Y);
void HLine(u_int X);
void VLine(u_int Y);
void LineToXY(u_int X, u_int Y);
void Arc(u_int radius, u_int begin_angle, u_int end_angle);
void CircleR(u_int radius);
void CircleRFill(u_int radius);
void Box(u_int X_2, u_int Y_2);
void BoxFill(u_int X_2, u_int Y_2);
void PutBitmap(u_int width, u_int height, u_int * array,int arr_len);
void PutSFIcon(u_int IconID);
void PutIcon(u_int iconID);
void Picture(u_int * arr, int arr_len);
void SelectFont(u_int fontNumber);
void SetBGColor(u_int color);
void TextNorth();
void TextEast();
void TextSouth();
void TextWest();
void PrintChar(u_int ASCII);
void PrintCharBG(u_int ASCII);
void PrintString(char str[], int str_len);
void PrintStringBG(char str[], int str_len);


//Function Prototypes
void DrawBlock(int x, int y,int color);
void DrawScores();
void DrawGrid();
void LCDOpen();
void LCDCmd(u_int cmd);
void drawScreen();
void DrawString(u_int font, u_int color, u_int x, u_int y, char * msg, u_int msgLen);
 
